@@ -415,7 +415,7 @@ TSputSQL <- function(x, serIDs=seriesNames(x), con, Table=NULL,
   #ids <- gsub(" ", "", serIDs ) # remove spaces in id
   #if(! all( ids == serIDs)) warning("spaces removed from series names.")
   rP <- TSrefperiod(x)
-  N <- periods(x)
+  #N <- NROW(x) # could be periods() (or Tobs())
   # SHOULD PROBABLY HAVE METHODS FOR TS, ZOO, ITS, ... HERE
   if(is.ts(x)) {
     fr <-frequency(x) 
@@ -663,14 +663,17 @@ TSgetSQL <- function(serIDs, con, TSrepresentation=getOption("TSrepresentation")
     if(TSdescription) desc <- c(desc, TSdescription(serIDs[i],con) ) # where?
     if(TSdoc)         doc  <- c(doc,  TSdoc(serIDs[i],con) ) # where?
     if(TSlabel)       label<- c(label,TSlabel(serIDs[i],con) ) # where?
+
     mat <- tbind(mat, r)
     } # where[j]
     } # serID[i]
   mat <- tfwindow(mat, tf=tf, start=start, end=end)
   if( (!all(is.na(rp))) && !all(rp == "	" ) ) TSrefperiod(mat) <- rp      
   
-  if (! TSrepresentation  %in% c( "zoo", "default"))
-      mat <- do.call(TSrepresentation, list(mat))   
+  if (! TSrepresentation  %in% c( "zoo", "default")){
+      require("tframePlus")
+      mat <- changeTSrepresentation(mat, TSrepresentation)
+      }
 
   seriesNames(mat) <- names
 
@@ -683,7 +686,6 @@ TSgetSQL <- function(serIDs, con, TSrepresentation=getOption("TSrepresentation")
   mat
   }
 
-
 setGeneric("TSdates", def=
    function(serIDs, con=getOption("TSconnection"), 
            vintage=getOption("TSvintage"), panel=getOption("TSpanel"), ...)
